Learn R Programming

psychonetrics (version 0.17.8)

logbook: Retrieve the psychonetrics logbook

Description

This function can be used to retrieve the logbook of a 'psychonetrics' object.

Usage

logbook(x, log = TRUE)

Value

A list of log entries (objects of class psychonetrics_log) stored in the model.

Arguments

x

A 'psychonetrics' object.

log

Logical, should the entry that the logbook is accessed be added?

Author

Sacha Epskamp