Learn R Programming

psychonetrics (version 0.17.8)

ml_tsdlvm1: Multi-level Lag-1 dynamic latent variable model family of psychonetrics models for time-series data

Description

Deprecated. Use dlvm1 directly with long-format data instead (set vars to a character vector and provide idvar).

This function is a deprecated wrapper around dlvm1 that allows for specifying the model using a long format data and similar input as the mlVAR package. The ml_ts_lvgvar simply sets within_latent = "ggm" and between_latent = "ggm" by default. These functions now call dlvm1() directly and emit deprecation warnings. (The observed-variable wrappers ml_var and ml_gvar are now aliases for ml_var1 and ml_gvar1, and are documented there.)

Usage

ml_tsdlvm1(data, beepvar, idvar, vars, groups, estimator = "FIML", 
  standardize = c("none", "z", "quantile"), ...)

ml_ts_lvgvar(...)

Value

An object of the class psychonetrics (psychonetrics-class).

Arguments

data

The data to be used. Must be raw data in long format (each row indicates one person at one time point).

beepvar

Optional string indicating assessment beep per day. Adding this argument will cause non-consecutive beeps to be treated as missing!

idvar

String indicating the subject ID

vars

Vectors of variables to include in the analysis

groups

An optional string indicating the name of the group variable in data.

estimator

Estimator to be used. Must be "FIML".

standardize

Which standardization method should be used? "none" (default) for no standardization, "z" for z-scores, and "quantile" for a non-parametric transformation to the quantiles of the marginal standard normal distribution.

...

Arguments sent to dlvm1

Author

Sacha Epskamp <mail@sachaepskamp.com>