Learn R Programming

psychonetrics (version 0.17.8)

psychonetrics_log-class: Class "psychonetrics_log"

Description

A logbook entry in the psychonetrics logbook

Arguments

Objects from the Class

Objects can be created by calls of the form new("psychonetrics_log", ...).

Slots

event:

Object of class "character": a description of the logged event.

time:

Object of class "POSIXct": the time at which the event was logged.

sessionInfo:

Object of class "sessionInfo": the R session information at the time of the event.

Methods

show

signature(object = "psychonetrics_log"): ...

Author

Sacha Epskamp

Examples

Run this code
showClass("psychonetrics_log")

Run the code above in your browser using DataLab