Learn R Programming

psychonetrics (version 0.4)

compare: Model comparison

Description

This function will print a table comparing multiple models on chi-square, AIC and BIC.

Usage

compare(...)

Arguments

Any number of psychonetrics models. Can be named to change the rownames of the output.

Value

A data frame with chi-square values, degrees of freedoms, RMSEAs, AICs, and BICs.