powered by
This function will print a table comparing multiple models on chi-square, AIC and BIC.
compare(...)
Any number of psychonetrics models. Can be named to change the rownames of the output.
psychonetrics
A data frame with chi-square values, degrees of freedoms, RMSEAs, AICs, and BICs.