powered by
This function can be used to retrieve the logbook of a 'psychonetrics' object.
logbook(x, log = TRUE)
A list of log entries (objects of class psychonetrics_log) stored in the model.
psychonetrics_log
A 'psychonetrics' object.
Logical, should the entry that the logbook is accessed be added?
Sacha Epskamp