- data
A data frame containing time-series data for multiple studies. Use together with studyvar to identify studies.
- covs
A list of pre-computed Toeplitz covariance matrices (one per study). Each matrix should have dimension 2p x 2p where p is the number of variables, with the first p rows/columns being lagged variables and the second p being current variables. Alternative to data.
- nobs
A vector with the number of observations per study. Required when covs is supplied.
- vars
Character vector of observed variable names. If missing, inferred from data.
- studyvar
A string indicating the column name in data that identifies the study. Required when data is supplied. If not supplied but idvar is, idvar is used as studyvar with a warning.
- idvar
Optional string indicating the subject ID column within each study. When both studyvar and idvar are supplied, data is first split by studyvar, then idvar is used within each study to collate time series (as in var1).
- dayvar
Optional string indicating the day variable (passed to tsData per study).
- beepvar
Optional string indicating the beep variable within day (passed to tsData per study).
- contemporaneous
Parameterization of the contemporaneous (residual innovation) covariance structure. One of "cov", "chol", "prec", "ggm", or "cor".
- beta
Temporal lag-1 regression matrix specification. Defaults to "full" (all elements free, including diagonal autoregressive effects).
- omega_zeta
Contemporaneous partial correlation matrix specification (used when contemporaneous = "ggm").
- delta_zeta
Contemporaneous scaling matrix specification (used when contemporaneous = "ggm").
- kappa_zeta
Contemporaneous precision matrix specification (used when contemporaneous = "prec").
- sigma_zeta
Contemporaneous covariance matrix specification (used when contemporaneous = "cov").
- lowertri_zeta
Contemporaneous Cholesky factor specification (used when contemporaneous = "chol").
- randomEffects
Parameterization of the random effects covariance structure.
- sigma_randomEffects
Random effects covariance matrix specification (used when randomEffects = "cov").
- kappa_randomEffects
Random effects precision matrix specification (used when randomEffects = "prec").
- omega_randomEffects
Random effects partial correlation matrix specification (used when randomEffects = "ggm").
- lowertri_randomEffects
Random effects Cholesky factor specification (used when randomEffects = "chol").
- delta_randomEffects
Random effects scaling matrix specification (used when randomEffects = "ggm").
- rho_randomEffects
Random effects correlation matrix specification (used when randomEffects = "cor").
- SD_randomEffects
Random effects standard deviation matrix specification (used when randomEffects = "cor").
- Vmats
Optional list with 'V' matrices (sampling error variance approximations).
- Vmethod
Which method should be used to approximate the sampling error variance? "individual" or "pooled".
- Vestimation
How should the sampling error estimates be evaluated? "averaged" or "per_study".
- baseline_saturated
Logical indicating if baseline and saturated models should be included.
- optimizer
The optimizer to be used. Defaults to "nlminb".
- estimator
The estimator to be used. "ML" or "FIML" (default).
- sampleStats
Optional sample statistics object.
- verbose
Logical, should progress be printed?
- bootstrap
Should the data be bootstrapped?
- boot_sub
Proportion of cases to subsample for bootstrap.
- boot_resample
Logical, should bootstrap be with replacement?
- rho_zeta
Only used when contemporaneous = "cor". Contemporaneous (innovation) correlation matrix specification ("full", "zero", or a pattern matrix).
- SD_zeta
Only used when contemporaneous = "cor". Diagonal matrix of contemporaneous (innovation) standard deviations ("full", "diag", or a pattern matrix).
- ...
Arguments sent to meta_var1.