powered by
"psychonetrics_log"
A logbook entry in the psychonetrics logbook
Objects can be created by calls of the form new("psychonetrics_log", ...).
new("psychonetrics_log", ...)
event
Object of class "character": a description of the logged event.
"character"
time
Object of class "POSIXct": the time at which the event was logged.
"POSIXct"
sessionInfo
Object of class "sessionInfo": the R session information at the time of the event.
"sessionInfo"
signature(object = "psychonetrics_log"): ...
signature(object = "psychonetrics_log")
Sacha Epskamp
showClass("psychonetrics_log")
Run the code above in your browser using DataLab